@@ -32,7 +32,7 @@ def r_moment(data, p_range=None, args={}, k=1, acc=0.1):
     
     Parameters
     ----------
-    fdata: 1-D list or function, a sample or probability density function
+    fdata: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     k: int, callable, orders, default=1
@@ -73,7 +73,7 @@ def ex(data, p_range=None, args={}, acc=0.1):
     
     Parameters
     ----------
-    fdata: 1-D list or function, a sample or probability density function
+    fdata: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     acc: float, callable, integration accuracy, it's effective only when data is function, default=0.1
@@ -114,7 +114,7 @@ def c_moment(data, p_range=None, args={}, k=1, acc=0.1):
     
     Parameters
     ----------
-    data: 1-D list or function, a sample or probability density function
+    data: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     k: int, callable, orders, default=1
@@ -157,7 +157,7 @@ def dx(data, p_range=None, args={}, acc=0.1):
     
     Parameters
     ----------
-    data: 1-D list or function, a sample or probability density function
+    data: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     acc: float, callable, integration accuracy, it's effective only when data is function, default=0.1
@@ -189,7 +189,7 @@ def skew(data, p_range=None, args={}, acc=0.1):
     
     Parameters
     ----------
-    data: 1-D list or function, a sample or probability density function
+    data: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     acc: float, callable, integration accuracy, it's effective only when data is function, default=0.1
@@ -221,7 +221,7 @@ def kurt(data, p_range=None, args={}, acc=0.1):
     
     Parameters
     ----------
-    data: 1-D list or function, a sample or probability density function
+    data: 1D list or function, a sample or probability density function
     p_range：tuple, callable, lower and upper limit of calculation
     args: dict, callable, pass other parameters to func
     acc: float, callable, integration accuracy, it's effective only when data is function, default=0.1
@@ -249,7 +249,7 @@ def mle(func, data, p_range, acc=0.1):
     
     返回
     ----
-    1-D ndarray，最佳的参数值
+    1D ndarray，最佳的参数值
 
 
     Maximum Likelihood Estimate
@@ -259,14 +259,14 @@ def mle(func, data, p_range, acc=0.1):
     ----------
     func：function, probability density function, the form of func should be as follows：
         def func(x, param):
-        x is a number or a vector, random variable; param is 1-D ndarray, undetermined parameters
-    data：1-D or 2-D array，samples
-    p_range：2-D array, callable, value range of undetermined parameters
+        x is a number or a vector, random variable; param is 1D ndarray, undetermined parameters
+    data：1D or 2D array，samples
+    p_range：2D array, callable, value range of undetermined parameters
     acc：num, callable, accuracy, default=0.1
     
     Return
     ------
-    1-D ndarray, the best parameter value
+    1D ndarray, the best parameter value
     '''
     # 构建似然函数的相反数
     def Lmin(theta, data):
@@ -311,7 +311,7 @@ def inde_test(data):
     
     Parameter
     ---------
-    data: 2-D array
+    data: 2D array
     
     Return
     ------
@@ -338,8 +338,8 @@ class DF1d():
     
     参数
     ----
-    sample：1-D列表，样本点
-    span：1-D数组，区间间隔，如span = [a, b, c]则将区间分为[a, b]和[b, c]，并统计各区间频率
+    sample：1D列表，样本点
+    span：1D数组，区间间隔，如span = [a, b, c]则将区间分为[a, b]和[b, c]，并统计各区间频率
     kind：浮点数类型或整型，可选，将插值类型指定为字符串('linear'、'nearest'、'zero'、'slinear'、'squardic'、'previous'、'next'，其中'zero'、'slinear'、'squared'和'cubic'表示零阶、一阶、二阶或三阶样条曲线插值；'previous'和'next'只返回点的上一个或下一个值)或作为一个整数指定要使用的样条曲线插值器的顺序。默认为'linear'
     
     属性
@@ -347,13 +347,13 @@ class DF1d():
     f：概率密度函数
     
     
-    One-dimension distribution fitting
+    1D distribution fitting
     Approximation of probability density function by frequency distribution function
     
     Parameters
     ----------
-    sample: 1-D list, samples
-    span: 1-D array, span of intervals, e.g. span = [a, b, c] will divide the interval into [a, b] and [b, c], and count the frequency of each interval
+    sample: 1D list, samples
+    span: 1D array, span of intervals, e.g. span = [a, b, c] will divide the interval into [a, b] and [b, c], and count the frequency of each interval
     kind: float or int, callable, specifies the kind of interpolation as a string ('linear', 'nearest', 'zero', 'slinear', 'quadratic', 'cubic', 'previous', 'next', where 'zero', 'slinear', 'quadratic' and 'cubic' refer to a spline interpolation of zeroth, first, second or third order; 'previous' and 'next' simply return the previous or next value of the point) or as an integer specifying the order of the spline interpolator to use. default='linear'
     
     Attribution
@@ -483,7 +483,7 @@ class DFT():
         return data_list, pro_list
     
     
-    def __con_fit(self, data, func, num_data, param, acc):
+    def __con_fit(self, data, func, num_data, args, acc):
         data = sorted(data)
         
         # 从小到大按20个一组分成多个部分
@@ -503,11 +503,11 @@ class DFT():
         pro_list = []
         if self.__func_type == 'pdf':
             for i in data_list:
-                pro_list.append(inte(func, [[i[0], i[-1]]], param=param, acc=acc))
+                pro_list.append(inte(func, [[i[0], i[-1]]], args=args, acc=acc))
         
         elif self.__func_type == 'cdf':
             for i in data_list:
-                pro_list.append(func(i[-1], **param) - func(i[0], **param))
+                pro_list.append(func(i[-1], **args) - func(i[0], **args))
         
         pro_list = np.array(pro_list) * num_data
         
@@ -519,7 +519,7 @@ class DFT():
         return data_list, pro_list
     
 
-    def __dis_fit(self, data, func, num_data, param):
+    def __dis_fit(self, data, func, num_data, args):
         data = list(data)
         data_set = sorted(set(data))
 
@@ -528,7 +528,7 @@ class DFT():
         pro_list = []
         for i in data_set:
             data_list.append(data.count(i))
-            pro_list.append(func(i, **param))
+            pro_list.append(func(i, **args))
         data_list = np.array(data_list)
         pro_list = np.array(pro_list) * num_data
 
@@ -537,13 +537,13 @@ class DFT():
         return data_list, pro_list
     
     
-    def fit(self, data, func, param={}, acc=0.1):
+    def fit(self, data, func, args={}, acc=0.1):
         '''
         参数
         ----
         data：数据
         func：函数类型，分布函数或概率密度函数，函数的输入须为一个数
-        param：字典类型，可选，用于传递func中的其他参数
+        args：字典类型，可选，用于传递func中的其他参数
         acc：浮点数类型，可选，积分精度，仅func_type为'pdf'或'cdf'时有效，默认为0.1
         
         
@@ -551,18 +551,18 @@ class DFT():
         ----------
         data: data
         func: function, cumulative distribution function or probability density function, the input of func should be a number
-        param: dict, callable, pass other parameters to func
+        args: dict, callable, pass other parameters to func
         acc: float, callable, integration accuracy, it's effective only when func_type is 'pdf' or 'cdf', default=0.1
         '''
         self.__data = np.array(data, dtype=np.float)
         self.__func = func
-        self.__param = param
+        self.__args = args
         num_data = len(data)
         
         if self.__func_type != 'pmf':
-            data_list, pro_list = self.__con_fit(data, func, num_data, param, acc)
+            data_list, pro_list = self.__con_fit(data, func, num_data, args, acc)
         else:
-            data_list, pro_list = self.__dis_fit(data, func, num_data, param)
+            data_list, pro_list = self.__dis_fit(data, func, num_data, args)
         
         self.degree = len(pro_list) - 1
         self.chi2_value = sum((data_list - pro_list)**2 / pro_list)
@@ -575,7 +575,7 @@ class DFT():
         if self.__func_type == 'pmf':
             acc = 1
         x = np.arange(x_min, x_max, acc)
-        y = self.__func(x, **self.__param)
+        y = self.__func(x, **self.__args)
         
         func_type = type(y).__name__
         if func_type == 'int' or func_type == 'float':
